Results
========

.. currentmodule:: pysylph

AniResult
---------

.. autoclass:: pysylph.AniResult
   :special-members: __init__
   :inherited-members:
   :members:

ProfileResult
-------------

.. autoclass:: pysylph.ProfileResult
   :special-members: __init__
   :inherited-members:
   :members:
